# PythonStack

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**requirements** | [**RequirementsDef**](RequirementsDef.md) |  |
**requirements_format** | **list[str]** | Lockfile format - defaults to pipenv if not explicitly specified  | [optional]
**requirements_lock** | [**RequirementsLockDef**](RequirementsLockDef.md) |  |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

